@@ -6,7 +6,7 @@ use warnings;
 
 BEGIN {
 	$Error::TypeTiny::WrongNumberOfParameters::AUTHORITY = 'cpan:TOBYINK';
-	$Error::TypeTiny::WrongNumberOfParameters::VERSION   = '2.007_007';
+	$Error::TypeTiny::WrongNumberOfParameters::VERSION   = '2.007_008';
 }
 
 $Error::TypeTiny::WrongNumberOfParameters::VERSION =~ tr/_//d;
@@ -17,22 +17,32 @@ our @ISA = 'Error::TypeTiny';
 sub minimum { $_[0]{minimum} }
 sub maximum { $_[0]{maximum} }
 sub got     { $_[0]{got} }
+sub target  { $_[0]{target} }
 
 sub has_minimum { exists $_[0]{minimum} }
 sub has_maximum { exists $_[0]{maximum} }
+sub has_target  { exists $_[0]{target} }
 
 sub _build_message {
 	my $e = shift;
+	
+	my $base = 'Wrong number of parameters';
+	if ( $e->has_target ) {
+		$base .= sprintf( ' to %s', $e->target );
+	}
+	
 	if ( $e->has_minimum and $e->has_maximum and $e->minimum == $e->maximum ) {
 		return sprintf(
-			"Wrong number of parameters; got %d; expected %d",
+			"%s; got %d; expected %d",
+			$base,
 			$e->got,
 			$e->minimum,
 		);
 	}
 	elsif ( $e->has_minimum and $e->has_maximum and $e->minimum < $e->maximum ) {
 		return sprintf(
-			"Wrong number of parameters; got %d; expected %d to %d",
+			"%s; got %d; expected %d to %d",
+			$base,
 			$e->got,
 			$e->minimum,
 			$e->maximum,
@@ -40,14 +50,24 @@ sub _build_message {
 	}
 	elsif ( $e->has_minimum ) {
 		return sprintf(
-			"Wrong number of parameters; got %d; expected at least %d",
+			"%s; got %d; expected at least %d",
+			$base,
 			$e->got,
 			$e->minimum,
 		);
 	}
+	elsif ( $e->has_maximum ) {
+		return sprintf(
+			"%s; got %d; expected at most %d",
+			$base,
+			$e->got,
+			$e->maximum,
+		);
+	}
 	else {
 		return sprintf(
-			"Wrong number of parameters; got %d",
+			"%s; got %d",
+			$base,
 			$e->got,
 		);
 	}
@@ -75,6 +95,10 @@ L<Type-Tiny stability policy|Type::Tiny::Manual::Policies/"STABILITY">.
 Thrown when a Type::Params compiled check is called with the wrong number
 of parameters.
 
+Also thrown by various parameterizable type constraints under similar
+circumstances. For example, the C<< HashRef[Int] >> makes sense, but
+C<< HashRef[Int, {}] >> does not.
+
 This package inherits from L<Error::TypeTiny>; see that for most
 documentation. Major differences are listed below:
 
@@ -94,13 +118,17 @@ The maximum expected number of parameters.
 
 The number of parameters actually passed to the compiled check.
 
+=item C<target>
+
+A short string describing what there was the wrong number of parameters for.
+
 =back
 
 =head2 Methods
 
 =over
 
-=item C<has_minimum>, C<has_maximum>
+=item C<has_minimum>, C<has_maximum>, C<has_target>
 
 Predicate methods.
 
