@@ -10,7 +10,7 @@ BEGIN {
 
 BEGIN {
 	$Type::Params::Signature::AUTHORITY  = 'cpan:TOBYINK';
-	$Type::Params::Signature::VERSION    = '2.007_007';
+	$Type::Params::Signature::VERSION    = '2.007_008';
 }
 
 $Type::Params::Signature::VERSION =~ tr/_//d;
@@ -21,6 +21,17 @@ use Types::Standard qw( -is -types -assert );
 use Types::TypeTiny qw( -is -types to_TypeTiny );
 use Type::Params::Parameter;
 
+my $Attrs = Enum[ qw/
+	caller_level package subname description _is_signature_for ID
+	method head tail parameters slurpy
+	message on_die next fallback strictness is_named allow_dash method_invocant
+	bless class constructor named_to_list list_to_named oo_trace
+	class_prefix class_attributes
+	returns_scalar returns_list
+	want_details want_object want_source can_shortcut coderef
+	quux
+/ ]; # quux for reasons
+
 sub _croak {
 	require Error::TypeTiny;
 	return Error::TypeTiny::croak( pop );
@@ -44,6 +55,16 @@ sub new {
 	$self->{class_prefix} ||= 'Type::Params::OO::Klass';
 	$self->{next}         ||= delete $self->{goto_next} if exists $self->{goto_next};
 	$self->BUILD;
+	$Attrs->all( sort keys %$self ) or do {
+		require Carp;
+		require Type::Utils;
+		my @bad = ( ~ $Attrs )->grep( sort keys %$self );
+		Carp::carp( sprintf(
+			"Warning: unrecognized signature %s: %s, continuing anyway",
+			@bad == 1 ? 'option' : 'options',
+			Type::Utils::english_list( @bad ),
+		) );
+	};
 	return $self;
 }
 
@@ -173,20 +194,25 @@ sub _rationalize_slurpies {
 sub _rationalize_returns {
 	my $self = shift;
 	
+	my $typify = sub {
+		my $ref = shift;
+		if ( is_Str $$ref ) {
+			require Type::Utils;
+			$$ref = Type::Utils::dwim_type( $$ref, $self->{package} ? ( for => $self->{package} ) : () );
+		}
+		else {
+			$$ref = to_TypeTiny( $$ref );
+		}
+	};
+	
 	if ( my $r = delete $self->{returns} ) {
+		$typify->( \ $r );
 		$self->{returns_scalar} ||= $r;
 		$self->{returns_list}   ||= ArrayRef->of( $r );
 	}
 
-	for my $attr ( qw/ returns_scalar returns_list / ) {
-		if ( is_Str $self->{$attr} ) {
-			require Type::Utils;
-			$self->{$attr} = Type::Utils::dwim_type( $self->{$attr}, $self->{package} ? ( for => $self->{package} ) : () );
-		}
-		elsif ( exists $self->{$attr} ) {
-			$self->{$attr} = to_TypeTiny( $self->{$attr} );
-		}
-	}
+	exists $self->{$_} && $typify->( \ $self->{$_} )
+		for qw/ returns_scalar returns_list /;
 	
 	return $self;
 }
@@ -966,6 +992,13 @@ sub _make_count_fail {
 		);
 	}
 
+	if ( my $package = $self->package and my $subname = $self->subname ) {
+		push @counts, sprintf(
+			'target => %s',
+			B::perlstring( "$package\::$subname" ),
+		) if $package ne '__ANON__' && $subname ne '__ANON__';
+	}
+
 	return sprintf(
 		$self->has_on_die
 			? q{return( "Error::TypeTiny::WrongNumberOfParameters"->throw_cb( $__ON_DIE__, %s ) )}
