@@ -10,7 +10,7 @@ BEGIN {
 
 BEGIN {
 	$Type::Tiny::AUTHORITY  = 'cpan:TOBYINK';
-	$Type::Tiny::VERSION    = '2.007_007';
+	$Type::Tiny::VERSION    = '2.007_008';
 	$Type::Tiny::XS_VERSION = '0.016';
 }
 
@@ -1185,6 +1185,23 @@ sub is_parameterized {
 	} #/ sub parameterize
 }
 
+sub check_parameter_count_for_parameterized_type {
+	my ( $library, $type_name, $args, $max_args, $min_args ) = @_;
+	$args = @$args if ref $args;
+	
+	if ( ( defined $max_args and $args > $max_args ) or ( defined $min_args and $args < $min_args ) ) {
+		require Error::TypeTiny::WrongNumberOfParameters;
+		Error::TypeTiny::WrongNumberOfParameters->throw(
+			target => "$library\::$type_name\[]",
+			( defined $min_args ) ? ( minimum => $min_args ) : (),
+			( defined $max_args ) ? ( maximum => $max_args ) : (),
+			got => $args,
+		);
+	}
+	
+	return;
+}
+
 sub child_type_class {
 	__PACKAGE__;
 }
@@ -2588,6 +2605,21 @@ anything useful.
 
 =back
 
+=head2 Functions
+
+=over
+
+=item *
+
+C<< check_parameter_count_for_parameterized_type( $lib, $typename, $args, $max, $min ) >>
+
+Utility function used by some types from Types::Standard, etc.
+
+Will throw a L<Error::TypeTiny::WrongNumberOfParameters> exception referencing
+C<< "$lib::\$typename\[]" >> if C<< $args >> is greater than C<< $max >> or
+less than C<< $min >>, if they're defined. If C<< $args >> is an arrayref,
+will use the length of the array.
+
 =head2 Overloading
 
 =over
