@@ -8,7 +8,7 @@ use warnings;
 
 BEGIN {
 	$Types::Standard::HashRef::AUTHORITY = 'cpan:TOBYINK';
-	$Types::Standard::HashRef::VERSION   = '2.007_007';
+	$Types::Standard::HashRef::VERSION   = '2.007_008';
 }
 
 $Types::Standard::HashRef::VERSION =~ tr/_//d;
@@ -24,6 +24,8 @@ no warnings;
 sub __constraint_generator {
 	return Types::Standard::HashRef unless @_;
 	
+	require Error::TypeTiny::WrongNumberOfParameters;
+	Type::Tiny::check_parameter_count_for_parameterized_type( 'Types::Standard', 'HashRef', \@_, 1 );
 	my $param = shift;
 	Types::TypeTiny::is_TypeTiny( $param )
 		or _croak(
